saraorepository

This repository contains all the information needed  to generate DOIS from
 datacite, create a webpage that shows all the data/reports being released and a
 how to upload data to a public bucket to be accessible to the users.
 
